==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QCborStreamReader_StringResult_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtcore-config.h>
#if QT_CONFIG(cborstreamreader)
#include <QtCore/qcborstreamreader.h>
#endif //QT_CONFIG(cborstreamreader)
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(cborstreamreader)


void deleter_QCborStreamReader_StringResult_QVariant_(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCborStreamReader::StringResult<QVariant>")
    QCborStreamReader::StringResult<QVariant> *_ptr = reinterpret_cast<QCborStreamReader::StringResult<QVariant> *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(cborstreamreader)

// emitting (writeConstructors)
// destruct QCborStreamReader::StringResult<QVariant>
void __qt_destruct_QCborStreamReader_StringResult_QVariant_(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCborStreamReader::StringResult<QVariant>")

#if QT_CONFIG(cborstreamreader)

    typedef QCborStreamReader::StringResult<QVariant> DESTRUCTOR;
    reinterpret_cast<QCborStreamReader::StringResult<QVariant>*>(ptr)->~DESTRUCTOR();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(cborstreamreader)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborStreamReader_00024StringResult_setData_1native_1cref_1QVariant__JLjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject data0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
#if QT_CONFIG(cborstreamreader)
        QCborStreamReader::StringResult<QVariant> *__qt_this = QtJambiAPI::objectFromNativeId<QCborStreamReader::StringResult<QVariant>>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QVariant  __qt_data0 = qtjambi_cast<QVariant >(__jni_env, data0);
        __qt_this->data = __qt_data0;
#else
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(data0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif //QT_CONFIG(cborstreamreader)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborStreamReader_00024StringResult_data_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
#if QT_CONFIG(cborstreamreader)
        QCborStreamReader::StringResult<QVariant> *__qt_this = QtJambiAPI::objectFromNativeId<QCborStreamReader::StringResult<QVariant>>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QVariant&  __qt_value = __qt_this->data;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif //QT_CONFIG(cborstreamreader)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborStreamReader_00024StringResult_setStatus_1native_1cref_1QCborStreamReader_1StringResultCode__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint status0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
#if QT_CONFIG(cborstreamreader)
        QCborStreamReader::StringResult<QVariant> *__qt_this = QtJambiAPI::objectFromNativeId<QCborStreamReader::StringResult<QVariant>>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QCborStreamReader::StringResultCode __qt_status0 = qtjambi_cast<QCborStreamReader::StringResultCode>(__jni_env, status0);
        __qt_this->status = QCborStreamReader::StringResultCode(__qt_status0);
#else
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(status0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif //QT_CONFIG(cborstreamreader)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborStreamReader_00024StringResult_status_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
#if QT_CONFIG(cborstreamreader)
        QCborStreamReader::StringResult<QVariant> *__qt_this = QtJambiAPI::objectFromNativeId<QCborStreamReader::StringResult<QVariant>>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QCborStreamReader::StringResultCode&  __qt_value = __qt_this->status;
        __java_return_value = __qt_value;
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif //QT_CONFIG(cborstreamreader)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborStreamReader_00024StringResult_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {

#if QT_CONFIG(cborstreamreader)

        const QCborStreamReader::StringResult<QVariant> *__qt_this = QtJambiAPI::objectFromNativeId<QCborStreamReader::StringResult<QVariant>>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);

#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(cborstreamreader)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCborStreamReader_StringResult_QVariant_(){
    using namespace RegistryAPI;

#if QT_CONFIG(cborstreamreader)

    const std::type_info& typeId = registerValueTypeInfo<QCborStreamReader::StringResult<QVariant>>("QCborStreamReader::StringResult<QVariant>", "io/qt/core/QCborStreamReader$StringResult");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCborStreamReader_StringResult_QVariant_, {
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCborStreamReader_StringResult_QVariant_);
    registerMetaType<QCborStreamReader::StringResult<QVariant>>("QCborStreamReader::StringResult<QVariant>");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(cborstreamreader)

}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QCborStreamReader_StringResult_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtcore-config.h>
#if QT_CONFIG(cborstreamreader)
#include <QtCore/qcborstreamreader.h>
#endif //QT_CONFIG(cborstreamreader)
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(cborstreamreader)


void deleter_QCborStreamReader_StringResult_QVariant_(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCborStreamReader::StringResult<QVariant>")
    QCborStreamReader::StringResult<QVariant> *_ptr = reinterpret_cast<QCborStreamReader::StringResult<QVariant> *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(cborstreamreader)

// emitting (writeConstructors)
// destruct QCborStreamReader::StringResult<QVariant>
void __qt_destruct_QCborStreamReader_StringResult_QVariant_(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCborStreamReader::StringResult<QVariant>")

#if QT_CONFIG(cborstreamreader)

    typedef QCborStreamReader::StringResult<QVariant> DESTRUCTOR;
    reinterpret_cast<QCborStreamReader::StringResult<QVariant>*>(ptr)->~DESTRUCTOR();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(cborstreamreader)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborStreamReader_00024StringResult_setData_1native_1cref_1QVariant__JLjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject data0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
#if QT_CONFIG(cborstreamreader)
        QCborStreamReader::StringResult<QVariant> *__qt_this = QtJambiAPI::objectFromNativeId<QCborStreamReader::StringResult<QVariant>>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QVariant  __qt_data0 = qtjambi_cast<QVariant >(__jni_env, data0);
        __qt_this->data = __qt_data0;
#else
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(data0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif //QT_CONFIG(cborstreamreader)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborStreamReader_00024StringResult_data_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
#if QT_CONFIG(cborstreamreader)
        QCborStreamReader::StringResult<QVariant> *__qt_this = QtJambiAPI::objectFromNativeId<QCborStreamReader::StringResult<QVariant>>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QVariant&  __qt_value = __qt_this->data;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif //QT_CONFIG(cborstreamreader)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborStreamReader_00024StringResult_setStatus_1native_1cref_1QCborStreamReader_1StringResultCode__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint status0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
#if QT_CONFIG(cborstreamreader)
        QCborStreamReader::StringResult<QVariant> *__qt_this = QtJambiAPI::objectFromNativeId<QCborStreamReader::StringResult<QVariant>>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QCborStreamReader::StringResultCode __qt_status0 = qtjambi_cast<QCborStreamReader::StringResultCode>(__jni_env, status0);
        __qt_this->status = QCborStreamReader::StringResultCode(__qt_status0);
#else
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(status0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif //QT_CONFIG(cborstreamreader)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborStreamReader_00024StringResult_status_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
#if QT_CONFIG(cborstreamreader)
        QCborStreamReader::StringResult<QVariant> *__qt_this = QtJambiAPI::objectFromNativeId<QCborStreamReader::StringResult<QVariant>>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QCborStreamReader::StringResultCode&  __qt_value = __qt_this->status;
        __java_return_value = __qt_value;
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif //QT_CONFIG(cborstreamreader)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborStreamReader_00024StringResult_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {

#if QT_CONFIG(cborstreamreader)

        const QCborStreamReader::StringResult<QVariant> *__qt_this = QtJambiAPI::objectFromNativeId<QCborStreamReader::StringResult<QVariant>>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QCborStreamReader::StringResult<QVariant>(*__qt_this));

#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(cborstreamreader)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCborStreamReader_StringResult_QVariant_(){
    using namespace RegistryAPI;

#if QT_CONFIG(cborstreamreader)

    const std::type_info& typeId = registerObjectTypeInfo<QCborStreamReader::StringResult<QVariant>>("QCborStreamReader::StringResult<QVariant>", "io/qt/core/QCborStreamReader$StringResult");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCborStreamReader_StringResult_QVariant_, {
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCborStreamReader_StringResult_QVariant_);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(cborstreamreader)

}
